####
Thot
####

Core functionality for Thot data management and analysis.

**This package is intended for developers.** If you simply want to use Thot for managing and analyzing your data, go to the `thot-data package <https://pypi.org/project/thot-data/>`_.

.. code-block:: bash

	python -m pip install thot-core

.. note::
	For full documentation go to `Read The Docs <https://thot-data-docs.readthedocs.io/en/latest/>`_.

.. note::
	For more features use hosted projects at `thot-data.com <http://www.thot-data.com>`_.

Thot is a framework for managing and analyzing data. Thot utilizes **top-down organization** and **bottom-up anlaysis** to make analyzing your data and drawing conclusions easy. This allows your data and your analysis to stay separate and modular.